<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [DataFrame][1]
    -   [toDict][2]
    -   [toArray][3]
    -   [toCollection][4]
    -   [toDSV][5]
    -   [toText][6]
    -   [toCSV][7]
    -   [toTSV][8]
    -   [toPSV][9]
    -   [toJSON][10]
    -   [show][11]
    -   [dim][12]
    -   [transpose][13]
    -   [count][14]
    -   [countValue][15]
    -   [push][16]
    -   [replace][17]
    -   [distinct][18]
    -   [unique][19]
    -   [listColumns][20]
    -   [select][21]
    -   [withColumn][22]
    -   [restructure][23]
    -   [renameAll][24]
    -   [rename][25]
    -   [castAll][26]
    -   [cast][27]
    -   [drop][28]
    -   [chain][29]
    -   [filter][30]
    -   [where][31]
    -   [find][32]
    -   [map][33]
    -   [reduce][34]
    -   [reduceRight][35]
    -   [dropDuplicates][36]
    -   [dropMissingValues][37]
    -   [fillMissingValues][38]
    -   [shuffle][39]
    -   [sample][40]
    -   [bisect][41]
    -   [groupBy][42]
    -   [sortBy][43]
    -   [union][44]
    -   [join][45]
    -   [innerJoin][46]
    -   [fullJoin][47]
    -   [outerJoin][48]
    -   [leftJoin][49]
    -   [rightJoin][50]
    -   [diff][51]
    -   [head][52]
    -   [tail][53]
    -   [slice][54]
    -   [getRow][55]
    -   [setRow][56]
    -   [setDefaultModules][57]
    -   [fromDSV][58]
    -   [fromText][59]
    -   [fromCSV][60]
    -   [fromTSV][61]
    -   [fromPSV][62]
    -   [fromJSON][63]

## DataFrame

[src/dataframe.js:30-1322][64]

DataFrame data structure providing an immutable, flexible and powerfull way to manipulate data with columns and rows.

**Parameters**

-   `data` **([Array][65] \| [Object][66] \| [DataFrame][67])** The data of the DataFrame.
-   `columns` **[Array][65]** The DataFrame column names.
-   `options` **[Object][66]** Additional options. Example: modules. (optional, default `{}`)

### toDict

[src/dataframe.js:371-378][68]

Convert DataFrame into dict / hash / object.

**Examples**

```javascript
df.toDict()
```

Returns **[Object][66]** The DataFrame converted into dict.

### toArray

[src/dataframe.js:387-391][69]

Convert DataFrame into Array of Arrays. You can also extract only one column as Array.

**Parameters**

-   `columnName` **[String][70]?** Column Name to extract. By default, all columns are transformed.

**Examples**

```javascript
df.toArray()
```

Returns **[Array][65]** The DataFrame (or the column) converted into Array.

### toCollection

[src/dataframe.js:400-402][71]

Convert DataFrame into Array of dictionnaries. You can also return Rows instead of dictionnaries.

**Parameters**

-   `ofRows` **[Boolean][72]?** Return a collection of Rows instead of dictionnaries.

**Examples**

```javascript
df.toCollection()
```

Returns **[Array][65]** The DataFrame converted into Array of dictionnaries (or Rows).

### toDSV

[src/dataframe.js:418-427][73]

Convert the DataFrame into a text delimiter separated values.
You can also save the file if you are using nodejs.

**Parameters**

-   `sep` **[String][70]** Column separator. (optional, default `' '`)
-   `header` **[Boolean][72]** Writing the header in the first line. If false, there will be no header. (optional, default `true`)
-   `path` **[String][70]?** The path to save the file. /!\\ Works only on node.js, not into the browser. (optional, default `undefined`)

**Examples**

```javascript
df.toDSV()
df.toDSV(';')
df.toDSV(';', true)
// From node.js only
df.toDSV(';', true, '/my/absolute/path/dataframe.txt')
```

Returns **[String][70]** The text file in raw string.

### toText

[src/dataframe.js:443-445][74]

Convert the DataFrame into a text delimiter separated values. Alias for .toDSV.
You can also save the file if you are using nodejs.

**Parameters**

-   `sep` **[String][70]** Column separator. (optional, default `' '`)
-   `header` **[Boolean][72]** Writing the header in the first line. If false, there will be no header. (optional, default `true`)
-   `path` **[String][70]?** The path to save the file. /!\\ Works only on node.js, not into the browser. (optional, default `undefined`)

**Examples**

```javascript
df.toText()
df.toText(';')
df.toText(';', true)
// From node.js only
df.toText(';', true, '/my/absolute/path/dataframe.txt')
```

Returns **[String][70]** The text file in raw string.

### toCSV

[src/dataframe.js:459-461][75]

Convert the DataFrame into a comma separated values string.
You can also save the file if you are using nodejs.

**Parameters**

-   `header` **[Boolean][72]** Writing the header in the first line. If false, there will be no header. (optional, default `true`)
-   `path` **[String][70]?** The path to save the file. /!\\ Works only on node.js, not into the browser. (optional, default `undefined`)

**Examples**

```javascript
df.toCSV()
df.toCSV(true)
// From node.js only
df.toCSV(true, '/my/absolute/path/dataframe.csv')
```

Returns **[String][70]** The csv file in raw string.

### toTSV

[src/dataframe.js:475-477][76]

Convert the DataFrame into a tab separated values string.
You can also save the file if you are using nodejs.

**Parameters**

-   `header` **[Boolean][72]** Writing the header in the first line. If false, there will be no header. (optional, default `true`)
-   `path` **[String][70]?** The path to save the file. /!\\ Works only on node.js, not into the browser. (optional, default `undefined`)

**Examples**

```javascript
df.toCSV()
df.toCSV(true)
// From node.js only
df.toCSV(true, '/my/absolute/path/dataframe.csv')
```

Returns **[String][70]** The csv file in raw string.

### toPSV

[src/dataframe.js:491-493][77]

Convert the DataFrame into a pipe separated values string.
You can also save the file if you are using nodejs.

**Parameters**

-   `header` **[Boolean][72]** Writing the header in the first line. If false, there will be no header. (optional, default `true`)
-   `path` **[String][70]?** The path to save the file. /!\\ Works only on node.js, not into the browser. (optional, default `undefined`)

**Examples**

```javascript
df.toPSV()
df.toPSV(true)
// From node.js only
df.toPSV(true, '/my/absolute/path/dataframe.csv')
```

Returns **[String][70]** The csv file in raw string.

### toJSON

[src/dataframe.js:505-513][78]

Convert the DataFrame into a json string. You can also save the file if you are using nodejs.

**Parameters**

-   `asCollection` **[Boolean][72]** Writing the JSON as collection of Object. (optional, default `true`)
-   `path` **[String][70]?** The path to save the file. /!\\ Works only on node.js, not into the browser. (optional, default `undefined`)

**Examples**

```javascript
df.toJSON()
// From node.js only
df.toJSON('/my/absolute/path/dataframe.json')
```

Returns **[String][70]** The json file in raw string.

### show

[src/dataframe.js:525-554][79]

Display the DataFrame as String Table. Can only return a sring instead of displaying the DataFrame.

**Parameters**

-   `rows` **[Number][80]** The number of lines to display. (optional, default `10`)
-   `quiet` **[Boolean][72]** Quiet mode. If true, only returns a string instead of console.log(). (optional, default `false`)

**Examples**

```javascript
df.show()
df.show(10)
const stringDF = df.show(10, true)
```

Returns **[String][70]** The DataFrame as String Table.

### dim

[src/dataframe.js:562-564][81]

Get the DataFrame dimensions.

**Examples**

```javascript
const [height, weight] = df.dim()
```

Returns **[Array][65]** The DataFrame dimensions. [height, weight]

### transpose

[src/dataframe.js:573-588][82]

Transpose a DataFrame. Rows become columns and conversely. n x p => p x n.

**Parameters**

-   `tranposeColumnNames`  
-   `transposeColumnNames` **[Boolean][72]** An option to transpose columnNames in a rowNames column. (optional, default `false`)

**Examples**

```javascript
df.transpose()
```

Returns **ÐataFrame** A new transposed DataFrame.

### count

[src/dataframe.js:596-598][83]

Get the rows number.

**Examples**

```javascript
df.count()
```

Returns **Int** The number of DataFrame rows.

### countValue

[src/dataframe.js:609-611][84]

Get the count of a value into a column.

**Parameters**

-   `valueToCount`  The value to count into the selected column.
-   `columnName` **[String][70]** The column to count the value. (optional, default `this.listColumns()[0]`)

**Examples**

```javascript
df.countValue(5, 'column2')
df.select('column1').countValue(5)
```

Returns **Int** The number of times the selected value appears.

### push

[src/dataframe.js:620-622][85]

Push new rows into the DataFrame.

**Parameters**

-   `rows` **([Array][65] | Row)** The rows to add.

**Examples**

```javascript
df.push([1,2,3], [1,4,9])
```

Returns **[DataFrame][67]** A new DataFrame with the new rows.

### replace

[src/dataframe.js:633-646][86]

Replace a value by another in all the DataFrame or in a column.

**Parameters**

-   `value`  The value to replace.
-   `replacement`  The new value.
-   `columnNames` **([String][70] \| [Array][65])** The columns to apply the replacement. (optional, default `this.listColumns()`)

**Examples**

```javascript
df.replace(undefined, 0, 'column1', 'column2')
```

Returns **[DataFrame][67]** A new DataFrame with replaced values.

### distinct

[src/dataframe.js:655-660][87]

Compute unique values into a column.

**Parameters**

-   `columnName` **[String][70]** The column to distinct.

**Examples**

```javascript
df.distinct('column1')
```

Returns **[DataFrame][67]** A DataFrame containing the column with distinct values.

### unique

[src/dataframe.js:670-672][88]

Compute unique values into a column.
Alias from .distinct()

**Parameters**

-   `columnName` **[String][70]** The column to distinct.

**Examples**

```javascript
df.unique('column1')
```

Returns **[DataFrame][67]** A DataFrame containing the column with distinct values.

### listColumns

[src/dataframe.js:680-682][89]

List DataFrame columns.

**Examples**

```javascript
df.listColumns()
```

Returns **[Array][65]** An Array containing DataFrame columnNames.

### select

[src/dataframe.js:691-696][90]

Select columns in the DataFrame.

**Parameters**

-   `columnNames` **...[String][70]** The columns to select.

**Examples**

```javascript
df.select('column1', 'column3')
```

Returns **[DataFrame][67]** A new DataFrame containing selected columns.

### withColumn

[src/dataframe.js:707-716][91]

Add a new column or set an existing one.

**Parameters**

-   `columnName` **[String][70]** The column to modify or to create.
-   `func` **[Function][92]** The function to create the column. (optional, default `(row,index)=>undefined`)

**Examples**

```javascript
df.withColumn('column4', () => 2)
df.withColumn('column2', (row) => row.get('column2') * 2)
```

Returns **[DataFrame][67]** A new DataFrame containing the new or modified column.

### restructure

[src/dataframe.js:727-729][93]

Modify the structure of the DataFrame by changing columns order, creating new columns or removing some columns.

**Parameters**

-   `newColumnNames` **[Array][65]** The new columns of the DataFrame.

**Examples**

```javascript
df.restructure(['column1', 'column4', 'column2', 'column3'])
df.restructure(['column1', 'column4'])
df.restructure(['column1', 'newColumn', 'column4'])
```

Returns **[DataFrame][67]** A new DataFrame with restructured columns (renamed, add or deleted).

### renameAll

[src/dataframe.js:738-743][94]

Rename each column.

**Parameters**

-   `newColumnNames` **[Array][65]** The new column names of the DataFrame.

**Examples**

```javascript
df.renameAll(['column1', 'column3', 'column4'])
```

Returns **[DataFrame][67]** A new DataFrame with the new column names.

### rename

[src/dataframe.js:753-758][95]

Rename a column.

**Parameters**

-   `columnName` **[String][70]** The column to rename.
-   `replacement` **[String][70]** The new name for the column.

**Examples**

```javascript
df.rename('column1', 'columnRenamed')
```

Returns **[DataFrame][67]** A new DataFrame with the new column name.

### castAll

[src/dataframe.js:767-780][96]

Cast each column into a given type.

**Parameters**

-   `typeFunctions` **[Array][65]** The functions used to cast columns.

**Examples**

```javascript
df.castAll([Number, String, (val) => new CustomClass(val)])
```

Returns **[DataFrame][67]** A new DataFrame with the columns having new types.

### cast

[src/dataframe.js:791-795][97]

Cast a column into a given type.

**Parameters**

-   `columnName` **[String][70]** The column to cast.
-   `typeFunction`  
-   `ObjectType` **[Function][92]** The function used to cast the column.

**Examples**

```javascript
df.cast('column1', Number)
df.cast('column1', (val) => new MyCustomClass(val))
```

Returns **[DataFrame][67]** A new DataFrame with the column having a new type.

### drop

[src/dataframe.js:804-809][98]

Remove a single column.

**Parameters**

-   `columnName` **[String][70]** The column to drop.

**Examples**

```javascript
df.drop('column2')
```

Returns **[DataFrame][67]** A new DataFrame without the dropped column.

### chain

[src/dataframe.js:824-829][99]

Chain maps and filters functions on DataFrame by optimizing their executions.
If a function returns boolean, it's a filter. Else it's a map.
It can be 10 - 100 x faster than standard chains of .map() and .filter().

**Parameters**

-   `funcs` **...[Function][92]** Functions to apply on the DataFrame rows taking the row as parameter.

**Examples**

```javascript
df.chain(
     row => row.get('column1') > 3, // filter
     row => row.set('column1', 3),  // map
     row => row.get('column2') === '5' // filter
)
```

Returns **[DataFrame][67]** A new DataFrame with modified rows.

### filter

[src/dataframe.js:839-853][100]

Filter DataFrame rows.

**Parameters**

-   `condition` **([Function][92] \| [Object][66])** A filter function or a column/value object.

**Examples**

```javascript
df.filter(row => row.get('column1') >= 3)
df.filter({'column2': 5, 'column1': 3}))
```

Returns **[DataFrame][67]** A new filtered DataFrame.

### where

[src/dataframe.js:864-866][101]

Filter DataFrame rows.
Alias of .filter()

**Parameters**

-   `condition` **([Function][92] \| [Object][66])** A filter function or a column/value object.

**Examples**

```javascript
df.where(row => row.get('column1') >= 3)
df.where({'column2': 5, 'column1': 3}))
```

Returns **[DataFrame][67]** A new filtered DataFrame.

### find

[src/dataframe.js:876-878][102]

Find a row (the first met) based on a condition.

**Parameters**

-   `condition` **([Function][92] \| [Object][66])** A filter function or a column/value object.

**Examples**

```javascript
df.find(row => row.get('column1') === 3)
df.find({'column1': 3})
```

Returns **Row** The targeted Row.

### map

[src/dataframe.js:887-892][103]

Map on DataFrame rows. /!\\ Prefer to use .chain().

**Parameters**

-   `func` **[Function][92]** A function to apply on each row taking the row as parameter.

**Examples**

```javascript
df.map(row => row.set('column1', row.get('column1') * 2))
```

Returns **[DataFrame][67]** A new DataFrame with modified rows.

### reduce

[src/dataframe.js:906-910][104]

Reduce DataFrame into a value.

**Parameters**

-   `func` **[Function][92]** The reduce function taking 2 parameters, previous and next.
-   `init`  The initial value of the reducer.

**Examples**

```javascript
df.reduce((p, n) => n.get('column1') + p, 0)
df2.reduce((p, n) => (
         n.set('column1', p.get('column1') + n.get('column1'))
          .set('column2', p.get('column2') + n.get('column2'))
))
```

Returns **any** A reduced value.

### reduceRight

[src/dataframe.js:920-924][105]

Reduce DataFrame into a value, starting from the last row (see .reduce()).

**Parameters**

-   `func` **[Function][92]** The reduce function taking 2 parameters, previous and next.
-   `init`  The initial value of the reducer.

**Examples**

```javascript
df.reduceRight((p, n) => p > n ? p : n, 0)
```

Returns **any** A reduced value.

### dropDuplicates

[src/dataframe.js:933-939][106]

Return a DataFrame without duplicated columns.

**Parameters**

-   `columnNames` **...[String][70]** The columns used to check unicity of rows. If omitted, unicity is checked on all columns.

**Examples**

```javascript
df.dropDuplicates('id', 'name')
```

Returns **[DataFrame][67]** A DataFrame without duplicated rows.

### dropMissingValues

[src/dataframe.js:948-962][107]

Return a DataFrame without rows containing missing values (undefined, NaN, null).

**Parameters**

-   `columnNames` **[Array][65]** The columns to consider. All columns are considered by default.

**Examples**

```javascript
df.dropMissingValues(['id', 'name'])
```

Returns **[DataFrame][67]** A DataFrame without rows containing missing values.

### fillMissingValues

[src/dataframe.js:972-974][108]

Return a DataFrame with missing values (undefined, NaN, null) fill with default value.

**Parameters**

-   `replacement`  The new value.
-   `columnNames` **[Array][65]** The columns to consider. All columns are considered by default.

**Examples**

```javascript
df.fillMissingValues(0, ['id', 'name'])
```

Returns **[DataFrame][67]** A DataFrame with missing values replaced.

### shuffle

[src/dataframe.js:982-993][109]

Return a shuffled DataFrame rows.

**Examples**

```javascript
df.shuffle()
```

Returns **[DataFrame][67]** A shuffled DataFrame.

### sample

[src/dataframe.js:1002-1016][110]

Return a random sample of rows.

**Parameters**

-   `percentage` **[Number][80]** A percentage of the orignal DataFrame giving the sample size.

**Examples**

```javascript
df.sample(0.3)
```

Returns **[DataFrame][67]** A sample DataFrame

### bisect

[src/dataframe.js:1025-1042][111]

Randomly split a DataFrame into 2 DataFrames.

**Parameters**

-   `percentage` **[Number][80]** A percentage of the orignal DataFrame giving the first DataFrame size. The second takes the rest.

**Examples**

```javascript
const [30DF, 70DF] = df.bisect(0.3)
```

Returns **[Array][65]** An Array containing the two DataFrames. First, the X% DataFrame then the rest DataFrame.

### groupBy

[src/dataframe.js:1055-1057][112]

Group DataFrame rows by columns giving a GroupedDataFrame object. See its doc for more examples.

**Parameters**

-   `columnNames` **...[String][70]** The columns used for the groupBy.

**Examples**

```javascript
df.groupBy('column1')
df.groupBy('column1', 'column2')
df.groupBy('column1', 'column2').listGroups()
df.groupBy('column1', 'column2').show()
df.groupBy('column1', 'column2').aggregate((group) => group.count())
```

Returns **GroupedDataFrame** A GroupedDataFrame object.

### sortBy

[src/dataframe.js:1070-1132][113]

Sort DataFrame rows based on column values. The row should contains only one variable type. Columns are sorted left-to-right.

**Parameters**

-   `columnNames` **([String][70] \| [Array][65]&lt;[string][70]>)** The columns giving order.
-   `reverse` **[Boolean][72]** Reverse mode. Reverse the order if true. (optional, default `false`)
-   `missingValuesPosition` **[String][70]** Define the position of missing values (undefined, nulls and NaN) in the order. (optional, default `'first'`)

**Examples**

```javascript
df.sortBy('id')
df.sortBy(['id1', 'id2'])
df.sortBy(['id1'], true)
```

Returns **[DataFrame][67]** An ordered DataFrame.

### union

[src/dataframe.js:1141-1154][114]

Concat two DataFrames.

**Parameters**

-   `dfToUnion` **[DataFrame][67]** The DataFrame to concat.

**Examples**

```javascript
df.union(df2)
```

Returns **[DataFrame][67]** A new concatenated DataFrame resulting of the union.

### join

[src/dataframe.js:1165-1174][115]

Join two DataFrames.

**Parameters**

-   `dfToJoin` **[DataFrame][67]** The DataFrame to join.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the join.
-   `how` **[String][70]** The join mode. Can be: full, inner, outer, left, right. (optional, default `'inner'`)

**Examples**

```javascript
df.join(df2, 'column1', 'full')
```

Returns **[DataFrame][67]** The joined DataFrame.

### innerJoin

[src/dataframe.js:1186-1188][116]

Join two DataFrames with inner mode.

**Parameters**

-   `dfToJoin` **[DataFrame][67]** The DataFrame to join.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the join.

**Examples**

```javascript
df.innerJoin(df2, 'id')
df.join(df2, 'id')
df.join(df2, 'id', 'inner')
```

Returns **[DataFrame][67]** The joined DataFrame.

### fullJoin

[src/dataframe.js:1199-1201][117]

Join two DataFrames with full mode.

**Parameters**

-   `dfToJoin` **[DataFrame][67]** The DataFrame to join.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the join.

**Examples**

```javascript
df.fullJoin(df2, 'id')
df.join(df2, 'id', 'full')
```

Returns **[DataFrame][67]** The joined DataFrame.

### outerJoin

[src/dataframe.js:1212-1214][118]

Join two DataFrames with outer mode.

**Parameters**

-   `dfToJoin` **[DataFrame][67]** The DataFrame to join.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the join.

**Examples**

```javascript
df2.outerJoin(df2, 'id')
df2.join(df2, 'id', 'outer')
```

Returns **[DataFrame][67]** The joined DataFrame.

### leftJoin

[src/dataframe.js:1225-1227][119]

Join two DataFrames with left mode.

**Parameters**

-   `dfToJoin` **[DataFrame][67]** The DataFrame to join.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the join.

**Examples**

```javascript
df.leftJoin(df2, 'id')
df.join(df2, 'id', 'left')
```

Returns **[DataFrame][67]** The joined DataFrame.

### rightJoin

[src/dataframe.js:1238-1240][120]

Join two DataFrames with right mode.

**Parameters**

-   `dfToJoin` **[DataFrame][67]** The DataFrame to join.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the join.

**Examples**

```javascript
df.rightJoin(df2, 'id')
df.join(df2, 'id', 'right')
```

Returns **[DataFrame][67]** The joined DataFrame.

### diff

[src/dataframe.js:1250-1252][121]

Find the differences between two DataFrames (reverse of join).

**Parameters**

-   `dfToDiff` **[DataFrame][67]** The DataFrame to diff.
-   `columnNames` **([String][70] \| [Array][65])** The selected columns for the diff.

**Examples**

```javascript
df2.diff(df2, 'id')
```

Returns **[DataFrame][67]** The differences DataFrame.

### head

[src/dataframe.js:1262-1264][122]

Create a new subset DataFrame based on the first rows.

**Parameters**

-   `nRows` **[Number][80]** The number of first rows to get. (optional, default `10`)

**Examples**

```javascript
df2.head()
df2.head(5)
```

Returns **[DataFrame][67]** The subset DataFrame.

### tail

[src/dataframe.js:1274-1276][123]

Create a new subset DataFrame based on the last rows.

**Parameters**

-   `nRows` **[Number][80]** The number of last rows to get. (optional, default `10`)

**Examples**

```javascript
df2.tail()
df2.tail(5)
```

Returns **[DataFrame][67]** The subset DataFrame.

### slice

[src/dataframe.js:1289-1297][124]

Create a new subset DataFrame based on given indexs. Similar to Array.slice.

**Parameters**

-   `startIndex` **[Number][80]** The index to start the slice (included). (optional, default `0`)
-   `endIndex` **[Number][80]** The index to end the slice (excluded). (optional, default `this.count()`)

**Examples**

```javascript
df2.slice()
df2.slice(0)
df2.slice(0, 20)
df2.slice(10, 30)
```

Returns **[DataFrame][67]** The subset DataFrame.

### getRow

[src/dataframe.js:1306-1308][125]

Return a Row by its index.

**Parameters**

-   `index` **[Number][80]** The index to select the row. (optional, default `0`)

**Examples**

```javascript
df2.getRow(1)
```

Returns **Row** The Row.

### setRow

[src/dataframe.js:1317-1321][126]

Modify a Row a the given index.

**Parameters**

-   `index` **[Number][80]** The index to select the row. (optional, default `0`)
-   `func`   (optional, default `row=>row`)

**Examples**

```javascript
df2.setRowByIndex(1, row => row.set("column1", 33))
```

Returns **[DataFrame][67]** A new DataFrame with the modified Row.

### setDefaultModules

[src/dataframe.js:37-39][127]

Set the default modules used in DataFrame instances.

**Parameters**

-   `defaultModules` **...[Object][66]** DataFrame modules used by default.

**Examples**

```javascript
DataFrame.setDefaultModules(SQL, Stat)
```

### fromDSV

[src/dataframe.js:54-73][128]

Create a DataFrame from a delimiter separated values text file. It returns a Promise.

**Parameters**

-   `pathOrFile` **([String][70] | File)** A path to the file (url or local) or a browser File object.
-   `sep` **[String][70]** The separator used to parse the file. (optional, default `";"`)
-   `header` **[Boolean][72]** A boolean indicating if the text has a header or not. (optional, default `true`)

**Examples**

```javascript
DataFrame.fromDSV('http://myurl/myfile.txt').then(df => df.show())
// In browser Only
DataFrame.fromDSV(myFile).then(df => df.show())
// From node.js only Only
DataFrame.fromDSV('/my/absolue/path/myfile.txt').then(df => df.show())
DataFrame.fromDSV('/my/absolue/path/myfile.txt', ';', true).then(df => df.show())
```

### fromText

[src/dataframe.js:88-90][129]

Create a DataFrame from a delimiter separated values text file. It returns a Promise. Alias of DataFrame.fromDSV.

**Parameters**

-   `pathOrFile` **([String][70] | File)** A path to the file (url or local) or a browser File object.
-   `sep` **[String][70]** The separator used to parse the file. (optional, default `";"`)
-   `header` **[Boolean][72]** A boolean indicating if the text has a header or not. (optional, default `true`)

**Examples**

```javascript
DataFrame.fromText('http://myurl/myfile.txt').then(df => df.show())
// In browser Only
DataFrame.fromText(myFile).then(df => df.show())
// From node.js only Only
DataFrame.fromText('/my/absolue/path/myfile.txt').then(df => df.show())
DataFrame.fromText('/my/absolue/path/myfile.txt', ';', true).then(df => df.show())
```

### fromCSV

[src/dataframe.js:104-106][130]

Create a DataFrame from a comma separated values file. It returns a Promise.

**Parameters**

-   `pathOrFile` **([String][70] | File)** A path to the file (url or local) or a browser File object.
-   `header` **[Boolean][72]** A boolean indicating if the csv has a header or not. (optional, default `true`)

**Examples**

```javascript
DataFrame.fromCSV('http://myurl/myfile.csv').then(df => df.show())
// For browser only
DataFrame.fromCSV(myFile).then(df => df.show())
// From node.js only
DataFrame.fromCSV('/my/absolue/path/myfile.csv').then(df => df.show())
DataFrame.fromCSV('/my/absolue/path/myfile.csv', true).then(df => df.show())
```

### fromTSV

[src/dataframe.js:120-122][131]

Create a DataFrame from a tab separated values file. It returns a Promise.

**Parameters**

-   `pathOrFile` **([String][70] | File)** A path to the file (url or local) or a browser File object.
-   `header` **[Boolean][72]** A boolean indicating if the tsv has a header or not. (optional, default `true`)

**Examples**

```javascript
DataFrame.fromTSV('http://myurl/myfile.tsv').then(df => df.show())
// For browser only
DataFrame.fromTSV(myFile).then(df => df.show())
// From node.js only
DataFrame.fromTSV('/my/absolue/path/myfile.tsv').then(df => df.show())
DataFrame.fromTSV('/my/absolue/path/myfile.tsv', true).then(df => df.show())
```

### fromPSV

[src/dataframe.js:136-138][132]

Create a DataFrame from a pipe separated values file. It returns a Promise.

**Parameters**

-   `pathOrFile` **([String][70] | File)** A path to the file (url or local) or a browser File object.
-   `header` **[Boolean][72]** A boolean indicating if the psv has a header or not. (optional, default `true`)

**Examples**

```javascript
DataFrame.fromPSV('http://myurl/myfile.psv').then(df => df.show())
// For browser only
DataFrame.fromPSV(myFile).then(df => df.show())
// From node.js only
DataFrame.fromPSV('/my/absolue/path/myfile.psv').then(df => df.show())
DataFrame.fromPSV('/my/absolue/path/myfile.psv', true).then(df => df.show())
```

### fromJSON

[src/dataframe.js:150-161][133]

Create a DataFrame from a JSON file. It returns a Promise.

**Parameters**

-   `pathOrFile` **([String][70] | File)** A path to the file (url or local) or a browser File object.

**Examples**

```javascript
DataFrame.fromJSON('http://myurl/myfile.json').then(df => df.show())
// For browser only
DataFrame.fromJSON(myFile).then(df => df.show())
// From node.js only
DataFrame.fromJSON('/my/absolute/path/myfile.json').then(df => df.show())
```

[1]: #dataframe

[2]: #todict

[3]: #toarray

[4]: #tocollection

[5]: #todsv

[6]: #totext

[7]: #tocsv

[8]: #totsv

[9]: #topsv

[10]: #tojson

[11]: #show

[12]: #dim

[13]: #transpose

[14]: #count

[15]: #countvalue

[16]: #push

[17]: #replace

[18]: #distinct

[19]: #unique

[20]: #listcolumns

[21]: #select

[22]: #withcolumn

[23]: #restructure

[24]: #renameall

[25]: #rename

[26]: #castall

[27]: #cast

[28]: #drop

[29]: #chain

[30]: #filter

[31]: #where

[32]: #find

[33]: #map

[34]: #reduce

[35]: #reduceright

[36]: #dropduplicates

[37]: #dropmissingvalues

[38]: #fillmissingvalues

[39]: #shuffle

[40]: #sample

[41]: #bisect

[42]: #groupby

[43]: #sortby

[44]: #union

[45]: #join

[46]: #innerjoin

[47]: #fulljoin

[48]: #outerjoin

[49]: #leftjoin

[50]: #rightjoin

[51]: #diff

[52]: #head

[53]: #tail

[54]: #slice

[55]: #getrow

[56]: #setrow

[57]: #setdefaultmodules

[58]: #fromdsv

[59]: #fromtext

[60]: #fromcsv

[61]: #fromtsv

[62]: #frompsv

[63]: #fromjson

[64]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L30-L1322 "Source code on GitHub"

[65]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[66]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[67]: #dataframe

[68]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L371-L378 "Source code on GitHub"

[69]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L387-L391 "Source code on GitHub"

[70]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[71]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L400-L402 "Source code on GitHub"

[72]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean

[73]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L418-L427 "Source code on GitHub"

[74]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L443-L445 "Source code on GitHub"

[75]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L459-L461 "Source code on GitHub"

[76]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L475-L477 "Source code on GitHub"

[77]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L491-L493 "Source code on GitHub"

[78]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L505-L513 "Source code on GitHub"

[79]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L525-L554 "Source code on GitHub"

[80]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[81]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L562-L564 "Source code on GitHub"

[82]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L573-L588 "Source code on GitHub"

[83]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L596-L598 "Source code on GitHub"

[84]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L609-L611 "Source code on GitHub"

[85]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L620-L622 "Source code on GitHub"

[86]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L633-L646 "Source code on GitHub"

[87]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L655-L660 "Source code on GitHub"

[88]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L670-L672 "Source code on GitHub"

[89]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L680-L682 "Source code on GitHub"

[90]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L691-L696 "Source code on GitHub"

[91]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L707-L716 "Source code on GitHub"

[92]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function

[93]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L727-L729 "Source code on GitHub"

[94]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L738-L743 "Source code on GitHub"

[95]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L753-L758 "Source code on GitHub"

[96]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L767-L780 "Source code on GitHub"

[97]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L791-L795 "Source code on GitHub"

[98]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L804-L809 "Source code on GitHub"

[99]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L824-L829 "Source code on GitHub"

[100]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L839-L853 "Source code on GitHub"

[101]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L864-L866 "Source code on GitHub"

[102]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L876-L878 "Source code on GitHub"

[103]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L887-L892 "Source code on GitHub"

[104]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L906-L910 "Source code on GitHub"

[105]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L920-L924 "Source code on GitHub"

[106]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L933-L939 "Source code on GitHub"

[107]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L948-L962 "Source code on GitHub"

[108]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L972-L974 "Source code on GitHub"

[109]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L982-L993 "Source code on GitHub"

[110]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1002-L1016 "Source code on GitHub"

[111]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1025-L1042 "Source code on GitHub"

[112]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1055-L1057 "Source code on GitHub"

[113]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1070-L1132 "Source code on GitHub"

[114]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1141-L1154 "Source code on GitHub"

[115]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1165-L1174 "Source code on GitHub"

[116]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1186-L1188 "Source code on GitHub"

[117]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1199-L1201 "Source code on GitHub"

[118]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1212-L1214 "Source code on GitHub"

[119]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1225-L1227 "Source code on GitHub"

[120]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1238-L1240 "Source code on GitHub"

[121]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1250-L1252 "Source code on GitHub"

[122]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1262-L1264 "Source code on GitHub"

[123]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1274-L1276 "Source code on GitHub"

[124]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1289-L1297 "Source code on GitHub"

[125]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1306-L1308 "Source code on GitHub"

[126]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L1317-L1321 "Source code on GitHub"

[127]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L37-L39 "Source code on GitHub"

[128]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L54-L73 "Source code on GitHub"

[129]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L88-L90 "Source code on GitHub"

[130]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L104-L106 "Source code on GitHub"

[131]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L120-L122 "Source code on GitHub"

[132]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L136-L138 "Source code on GitHub"

[133]: https://github.com/Gmousse/dataframe-js/blob/d9799cf5b2a27782abac516d0f7dc5be1db40dc8/src/dataframe.js#L150-L161 "Source code on GitHub"
